@@ -19,16 +19,10 @@ Devel::Ladybug::ExtID - Define inter-object relationships
 
   use Devel::Ladybug qw| :all |;
 
-  use YourApp::Parent;
-
-  create "YourApp::Child" => {
-    # refer to Parent by ID:
-    parentId => YourApp::Parent->assert,
-
-    # the above is shorthand for:
-    # parentId => Devel::Ladybug::ExtID->assert(
-    #   "YourApp::Parent"
-    # )
+  create "YourApp::ChildObject" => {
+    parentObjectId => Devel::Ladybug::ExtID->assert(
+      "YourApp::ParentObject"
+    )
   };
 
 =head1 DESCRIPTION
@@ -71,19 +65,19 @@ enforce database-level foreign key constraints.
 Create a class of object which refers to itself by parent ID:
 
   #
-  # File: YourApp/Parent.pm
+  # File: YourApp/ParentObject.pm
   #
   use strict;
   use warnings;
 
   use Devel::Ladybug qw| :all |;
 
-  create "YourApp::Parent" => {
+  create "YourApp::ParentObject" => {
     #
     # Folders can go in other folders:
     #
     parentId => Devel::Ladybug::ExtID->assert(
-      "YourApp::Parent",
+      "YourApp::ParentObject",
       subtype(
         optional => true
       )
@@ -101,15 +95,15 @@ which refers to it:
   use strict;
   use warnings;
 
-  use YourApp::Parent;
+  use YourApp::ParentObject;
 
-  my $parent = YourApp::Parent->new(
+  my $parent = YourApp::ParentObject->new(
     name => "Hello Parent"
   );
 
   $parent->save;
 
-  my $child = YourApp::Child"->new(
+  my $child = YourApp::ChildObject"->new(
     name => "Hello Child",
     parentId => $parent->id,
   );
@@ -122,17 +116,19 @@ A document class, building on the above example. Documents refer
 to their parent by ID:
 
   #
-  # File: YourApp/Child.pm
+  # File: YourApp/ChildObject.pm
   #
   use strict;
   use warnings;
 
   use Devel::Ladybug qw| :all |;
 
-  use YourApp::Parent; # You must "use" any external classes
+  use YourApp::ParentObject; # You must "use" any external classes
 
-  create "YourApp::Child" => {
-    parentId => YourApp::Parent->assert,
+  create "YourApp::ChildObject" => {
+    parentId => Devel::Ladybug::ExtID->assert(
+      "YourApp::ParentObject"
+    )
 
   };
 
@@ -145,11 +141,11 @@ parent:
   use strict;
   use warnings;
 
-  use YourApp::Child;
+  use YourApp::ChildObject;
 
-  my $parent = YourApp::Parent->loadByName("Hello Parent");
+  my $parent = YourApp::ParentObject->loadByName("Hello Parent");
 
-  my $child = YourApp::Child->new(
+  my $child = YourApp::ChildObject->new(
     name => "Hello Again",
     parentId => $parent->id
   );
@@ -168,8 +164,10 @@ to create a one-to-many relationship.
   # ...
 
   create "YourApp::OneToManyExample" => {
-    parentIds => Devel::Ladybug::Array->assert(
-      YourApp::Parent->assert
+    parentIds => Devel::Ladybug::Array->assert
+      Devel::Ladybug::ExtID->assert(
+        "YourApp::ParentObject"
+      )
     ),
 
     # ...
@@ -189,8 +187,11 @@ subtype argument.
   # ...
 
   create "YourApp::OneToOneExample" => {
-    parentId => YourApp::Parent->assert(
-      subtype( unique => true )
+    parentId => Devel::Ladybug::ExtID->assert(
+      "YourApp::ParentObject",
+      subtype(
+        unique => true
+      )
     ),
     
     # ...
@@ -206,7 +207,8 @@ This is entirely an application-level constraint, and is not enforced
 by the database when manually inserting or updating rows. Careful!
 
   create "YourApp::PickyExample" => {
-    userId => YourApp::Example::User->assert(
+    userId => Devel::Ladybug::ExtID->assert(
+      "YourApp::Example::::User",
       "select id from example_user where foo = 1"
     ),
 
@@ -232,26 +234,24 @@ by the database when manually inserting or updating rows. Careful!
 
 =head2 Same-table non-GUID keys
 
-Self-referential tables (tables which refer back to themselves by
-parent ID), with an ID assertion which is not of type
-L<Devel::Ladybug::ID>, should assert an appropriate column type in
-the ExtID assertion's subtype args. This workaround is only needed
-for self-referential tables which have overridden their C<id> column.
+Self-referential tables whose ID is not of type L<Devel::Ladybug::ID>
+should assert an appropriate column type. This is needed because at
+class creation time, Ladybug does not yet know anything about the
+ID of the class being created. This workaround is only needed for
+self-referential tables which have overridden their C<id> column.
 
-You do B<not> need to do this for externally referential tables,
+You do B<not> need to do this for externally referencing tables,
 since Ladybug will already know which column type to use. You do
 B<not> need to do this unless the C<id> assertion was overridden.
 
-  create "YourApp::FunkySelfRef" => {
-    id => Devel::Ladybug::Serial->assert(), # Overriding ID type
 
-    #
-    # Use ExtID->assert directly for self-ref tables:
-    #
+  create "YourApp::FunkySelfRef" => {
+    id => Devel::Ladybug::Serial->assert(),
+
     parentId => Devel::Ladybug::ExtID->assert(
       "YourApp::FunkySelfRef",
       subtype(
-        columnType => "INTEGER" # <-- Must match ID column type
+        columnType => "INTEGER"     # <-- eg
       )
     ),
 
@@ -281,18 +281,12 @@ sub assert {
     Devel::Ladybug::Type::__parseTypeArgs( Devel::Ladybug::Type::isStr,
     @rules );
 
-  my $asserts;
-
   if ( UNIVERSAL::isa( $externalClass, "Devel::Ladybug::Object" ) ) {
-    $asserts = $externalClass->get('ASSERTS');
-  }
-
-  if ( $asserts && $asserts->{id} ) {
     #
     # We already know what the foreign column type is, so just use
     # the same type here:
     #
-    $parsed{columnType} ||= $asserts->{id}->columnType;
+    $parsed{columnType} ||= $externalClass->asserts->{id}->columnType;
 
   } else {
     #
@@ -339,7 +333,6 @@ sub assert {
           $memberClass->__primaryKey, $memberClass->quote($value)
         );
 
-
         $exists = $externalClass->selectBool($q);
       } else {
         $exists = $memberClass->doesIdExist($value);
