@@ -21,6 +21,13 @@ Devel::Ladybug::Object - Abstract object class
 Base abstract object class for the Devel::Ladybug framework. Extends
 L<Devel::Ladybug::Class> with a constructor, getters, and setters.
 
+=head1 INHERITANCE
+
+This class inherits additional class and object methods from the
+following packages:
+
+L<Devel::Ladybug::Class> > Devel::Ladybug::Object
+
 =head1 PUBLIC CLASS METHODS
 
 =cut
@@ -35,10 +42,6 @@ use Devel::Ladybug::Type;
 use Devel::Ladybug::Enum::Bool;
 use Devel::Ladybug::Exceptions;
 
-use Devel::Ladybug::Persistence::MySQL;
-use Devel::Ladybug::Persistence::SQLite;
-use Devel::Ladybug::Persistence::PostgreSQL;
-
 use base qw| Devel::Ladybug::Class |;
 
 our $AUTOLOAD;
@@ -264,7 +267,7 @@ sub proto {
 =item * $class->attributes()
 
 Returns a flat list of allowed attributes, if any, for objects of this
-class.
+class. Includes any attribute names in C<__baseAsserts()>.
 
   my @keys = $class->attributes();
 
@@ -335,9 +338,9 @@ sub isAttributeAllowed {
     if ( exists $asserts->{$key} ) {
       return true;
     } else {
-      my ($caller,$pkg,$line) = caller();
+      my $caller = caller();
       warn
-        "BUG (Check $caller:$line): \"$key\" is not a member of \"$class\"";
+        "BUG (Check $caller): \"$key\" is not a member of \"$class\"";
       return false;
     }
   } else {
@@ -347,6 +350,25 @@ sub isAttributeAllowed {
 
 =pod
 
+=item * $class->asserts()
+
+Abstract method, implemented by subclasses to returns an
+Devel::Ladybug::Hash of assertion objects, including any base
+assertions which may be present.
+
+  my $asserts = $class->asserts();
+
+=cut
+
+sub asserts {
+  my $class = shift;
+
+  throw Devel::Ladybug::ClassIsAbstract(
+    "Abstract class $class will never have assertions");
+}
+
+=pod
+
 =item * $class->assert()
 
 Abstract method, implemented by subclasses to return an assertion
@@ -424,6 +446,16 @@ sub assert {
     "You may not assert attributes for abstract class $class");
 }
 
+sub elementClass {
+  my $class = shift;
+  my $key   = shift;
+
+  #
+  # Fine for abstract method
+  #
+  return undef;
+}
+
 =pod
 
 =back
@@ -473,10 +505,84 @@ sub import {
 
     # ref($type->{$key}) !~ /Hash|Array/i;
 
-    $class->__elementClass($key);
+    $class->elementClass($key);
   }
 }
 
+=pod
+
+=item * $class->__baseAsserts()
+
+Abstract method.
+
+Asserts are not inherited by subclasses, unless defined in the hash
+returned by this method. Override in subclass to provide a hash of
+inherited assertions.
+
+Unless implementing a new abstract class that uses special keys,
+__baseAsserts() does not need to be used or modified. Concrete classes
+should just use inline assertions as per the examples in
+L<Devel::Ladybug::Type>.
+
+C<__baseAsserts()> may be overridden as a C<sub{}> or as a class
+variable.
+
+Using a C<sub{}> lets you extend the parent class's base asserts, or
+use any other Perl operation to derive the appropriate values:
+
+  create "YourApp::Example" => {
+    #
+    # Inherit parent class's base asserts, tack on "foo"
+    #
+    __baseAsserts => sub {
+      my $class = shift;
+
+      my $base = $class->SUPER::__baseAsserts();
+
+      $base->{foo} = Devel::Ladybug::Str->assert();
+
+      return $base;
+    },
+
+    # ...
+  };
+
+One may alternately use a class variable to redefine base asserts,
+overriding the parent:
+
+  create "YourApp::Example" => {
+    #
+    # Statically assert two base attributes, "id" and "name"
+    #
+    __baseAsserts => {
+      id   => Devel::Ladybug::Int->assert(),
+
+      name => Devel::Ladybug::Str->assert()
+    },
+
+    # ...
+  }
+
+To inherit no base assertions:
+
+  create "Devel::Ladybug::RebelExample" => {
+    #
+    # Sometimes, parent doesn't know best:
+    #
+    __baseAsserts => { },
+
+    # ...
+  }
+
+=cut
+
+sub __baseAsserts {
+  my $class = shift;
+
+  throw Devel::Ladybug::ClassIsAbstract(
+    "Abstract class $class has no base asserts");
+}
+
 sub __assertClass {
   my $class = shift;
 
@@ -503,16 +609,6 @@ sub __assertClass {
   return $assertClass;
 }
 
-sub __elementClass {
-  my $class = shift;
-  my $key   = shift;
-
-  #
-  # Fine for abstract method
-  #
-  return undef;
-}
-
 =pod
 
 =back
@@ -537,12 +633,8 @@ sub get {
   my $class = $self->class();
 
   if ($class) {
-    if ( !$class->isAttributeAllowed($key) ) {
-      my ($caller,$pkg,$line) = caller();
-      Devel::Ladybug::RuntimeError->throw(
-        "BUG (Check $caller:$line): $self does not answer to $key"
-      );
-    }
+    throw Devel::Ladybug::RuntimeError("$key is not a member of $class")
+      if !$class->isAttributeAllowed($key);
 
     return $self->{$key};
   } else {
@@ -600,12 +692,12 @@ Removes all items, leaving self with zero elements.
     bar => "dos"
   );
 
-  print $object->count(); # 2
+  print $object->size(); # 2
   print "\n";
 
   $object->clear();
 
-  print $object->count(); # 0
+  print $object->size(); # 0
   print "\n";
 
 =cut
@@ -696,38 +788,6 @@ sub AUTOLOAD {
 
   my $class = $self->class();
 
-  do {
-    my $receiver = $class;
-
-    if ( !$receiver ) { $receiver = $self }
-
-    if ( $receiver->can("__useDbi") && $receiver->__useDbi ) {
-      my $delegate;
-
-      if ( $receiver->__useDbi == 1 ) {
-        $delegate = "Devel::Ladybug::Persistence::MySQL";
-      } elsif ( $receiver->__useDbi == 2 ) {
-        $delegate = "Devel::Ladybug::Persistence::SQLite";
-      } elsif ( $receiver->__useDbi == 3 ) {
-        $delegate = "Devel::Ladybug::Persistence::PostgreSQL";
-      }
-
-      if ( !defined( *{"$delegate\::$message"} ) ) {
-        $delegate = "Devel::Ladybug::Persistence::Generic";
-      }
-
-      if ( $delegate->can($message) ) {
-        do {
-          no strict "refs";
-
-          my $results = &{"$delegate\::$message"}( $self, @_ );
-
-          return $results;
-        };
-      }
-    }
-  };
-
   if ( !$class ) {
     $class = $self;
 
